/**
 * netfunc.h -- A basic networking library for implementing UDP and TCP 
 * client-server applications.
 *
 * Copyright (C) 2011 Pantelis A. Frangoudis <pfrag@aueb.gr>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef _NETFUNC_H_
#define _NETFUNC_H_

#include <stdio.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <sys/select.h>
#include <sys/time.h>
#include <unistd.h>
#include <string.h>

#define _PROTO_UDP_	1
#define _PROTO_TCP_	2

#define FROM_CLIENT	1
#define TO_SERVER	1
#define TO_CLIENT	0
#define FROM_SERVER	0

#define ERR_ACCEPT_ON_UDP	-10

struct cnx_info_t {
	int proto;
	char *host;
	short port;
	int sockfd;
	int cli_sockfd;
	struct sockaddr_in addr;
	struct sockaddr_in cliaddr;
};

int init_server(struct cnx_info_t* info);
int init_client_connection(struct cnx_info_t* info);
int accept_client_connection(struct cnx_info_t* info);
int write_data(struct cnx_info_t* info, void *data, int datalen, int to_server);
int read_data(struct cnx_info_t* info, void *data, int maxlen, int from_client);
int peek_data(struct cnx_info_t *info, void *data, int peek_data_len, int timeout, int from_client);
int wait_for_data(struct cnx_info_t* info, int msec, int from_client);
#endif

