/**
 * protocol.h -- Implementation of a simple text-based protocol for the 
 * communication between collectord and 11kd. 
 *
 * Copyright (C) 2011 Pantelis A. Frangoudis <pfrag@aueb.gr>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef _PROTOCOL_H_
#define _PROTOCOL_H_

#include <string.h>
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <errno.h>
#include <ctype.h>

#include "netfunc.h"

#define MTYPE_REPORT_REQUEST	10
#define MTYPE_REPORT_BATCH		20
#define MTYPE_NEW_CHANNEL		30

#define RBAT_HDR "RBAT"
#define RREQ_HDR "RREQ"
#define CASS_HDR "CASS"

#define PEEK_DATA_LEN 30

struct bss_info_t {
	unsigned char bss_mac[6];
	unsigned char user_mac[6];
	int channel;
	struct bss_info_t* next;
};

void bss_list_free(struct bss_info_t *list);

char *recv_protocol_message(struct cnx_info_t *info, int *mtype, int timeout, int from_client);
int xmit_protocol_message(struct cnx_info_t *info, char *message, int to_server);

char *generate_report_request();
int parse_report_request(char *message);

char *generate_report_batch(struct bss_info_t* list);
struct bss_info_t* parse_report_batch(char *message);

char *generate_channel_assignment(int channel);
int parse_channel_assignment(char *message);

char *msg_to_lower_case(char *msg, int len);
int generate_random_mac(void *mac);
#endif

